@@ -14,7 +14,7 @@ Usage:
 
 import os
 from .ssh_utils.utils import run_cmd
-from .ssh_utils.type_checks import is_file,is_dir
+from .file_utils.file_utils.type_checks import is_file,is_dir
 from .abstract_classes import run_pruned_func
 _FILE_PATH_KEYS = ['file', 'filepath', 'file_path', 'path', 'directory', 'f', 'dst', 'dest']
 _CONTENTS_KEYS = ['cont', 'content', 'contents', 'data', 'datas', 'dat', 'src', 'source']
